package com.agilecontrol.nea.core.control.web;

import com.agilecontrol.nea.core.control.web.UserWebImpl;
import com.agilecontrol.nea.core.control.web.WebUtils;
import com.agilecontrol.nea.core.control.web.binhandler.GetFile;
import com.agilecontrol.nea.core.schema.ClientManager;
import com.agilecontrol.nea.util.Configurations;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@WebServlet({"/servlets/userfolder/*"})
public class WebClientUserFileServlet extends HttpServlet {

   private static final Logger log = LoggerFactory.getLogger(WebClientUserFileServlet.class);
   private static final long serialVersionUID = 6766252586940749607L;
   public static final String USER_FOLDER_PATH = "/servlets/userfolder";
   private String clientWebRoot;


   public void init(ServletConfig config) throws ServletException {
      Class var2 = WebClientUserFileServlet.class;
      synchronized(WebClientUserFileServlet.class) {
         super.init(config);
         Configurations conf = (Configurations)WebUtils.getServletContextManager().getActor("nea.configs");
         this.clientWebRoot = conf.getProperty("client.webroot", "/act/webroot");
      }
   }

   public void service(HttpServletRequest req, HttpServletResponse res) throws IOException, ServletException {
      UserWebImpl userWeb = null;

      try {
         userWeb = (UserWebImpl)WebUtils.getSessionContextManager(req.getSession()).getActor("nea.web.authorization");
      } catch (Throwable var15) {
         ;
      }

      String domain = null;
      if(userWeb != null && userWeb.getUserId() != 1) {
         domain = userWeb.getClientDomain();
      } else {
         domain = ClientManager.getInstance().getDefaultClient().getDomain();
      }

      String path = this.clientWebRoot + "/" + domain + req.getPathInfo();
      File file = new File(path);
      if(!file.exists()) {
         log.warn(path + " not found");
      } else {
         long lastModified = file.lastModified();
         long ifModifiedSince = req.getDateHeader("If-Modified-Since");
         if(ifModifiedSince > 0L && ifModifiedSince == lastModified) {
            res.setStatus(304);
         } else {
            res.addHeader("Cache-Control", "max-age=0");
            res.setDateHeader("Last-Modified", lastModified);
            res.setContentType(this.guessContentType(file));
            res.setContentLength((int)file.length());
            FileInputStream is = new FileInputStream(file);
            ServletOutputStream os = res.getOutputStream();
            byte[] b = new byte[8192];

            int bInt;
            while((bInt = is.read(b, 0, b.length)) != -1) {
               os.write(b, 0, bInt);
            }

            os.close();
            is.close();
         }
      }
   }

   private String guessContentType(File file) {
      String fileExt = null;
      int p = file.getName().lastIndexOf(46);
      if(p > 0) {
         fileExt = file.getName().substring(p + 1);
      }

      if(fileExt != null) {
         for(int i = 0; i < GetFile.EXT.length; ++i) {
            if(GetFile.EXT[i].equals(fileExt)) {
               return GetFile.EXT_CONTENT_TYPE[i];
            }
         }
      }

      return "application/octetstream; charset=GBK";
   }

}
